package no.ntnu.idatt1002.demo.data.Economics;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Register class for Expense-objects.
 */
public class ExpenseRegister extends ItemRegister {
    private final List<Expense> expenses;

    /**
     * An "empty" class constructor.
     */
    public ExpenseRegister(){
        this.expenses = new ArrayList<>();
    }

    /**
     * Class constructor.
     * @param expenses an ArrayList with Expense´s you want to overview
     */
    public ExpenseRegister(ArrayList<Expense> expenses){
        this.expenses = expenses;
    }

    /**
     * Get a List of every Expense-object in expenses.
     * @return expenses.
     */
    public List<Expense> getExpenses() {
        return expenses;
    }

    /**
     * Add an Expense to expenses.
     * @param expense the Expense you want to add.
     * @throws IllegalArgumentException if expense is already registered.
     */
    public void addExpense(Expense expense) throws IllegalArgumentException{
        if(expenses.contains(expense)){
            throw new IllegalArgumentException("This expense is already in the register");
        }
        this.expenses.add(expense);
    }

    /**
     * Get every Expense of a given ExpenseCategory.
     * @param category the ExpenseCategory you want to find every Expense of.
     * @return a List with every Expense in expenses with the category.
     */
    public List<Expense> getExpenseBasedOnCategory(ExpenseCategory category){
        return expenses.stream().filter(anExpense -> anExpense.getCategory().compareTo(category) == 0).collect(Collectors.toList());
    }

}
