package no.ntnu.idatt1002.demo.data.Economics;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Register class for Income-objects.
 */
public class IncomeRegister extends ItemRegister{
    private final List<Income> incomes;

    /**
     * An "empty" class constructor.
     */
    public IncomeRegister(){
        this.incomes = new ArrayList<>();
    }

    /**
     * Class constructor.
     * @param incomes an ArrayList with Income´s you want to overview
     */
    public IncomeRegister(ArrayList<Income> incomes){
        this.incomes = incomes;
    }

    /**
     * Get a List of every Income-object in incomes.
     * @return incomes.
     */
    public Collection<Income> getExpenses() {
        return incomes;
    }

    /**
     * Add an Income to incomes.
     * @param income the Income you want to add.
     * @throws IllegalArgumentException if income is already registered.
     */
    public void addIncome(Income income){
        if(incomes.contains(income)){
            throw new IllegalArgumentException("This Income is already in the register.");
        }
        this.incomes.add(income);
    }

    /**
     * Get every Income of a given IncomeCategory.
     * @param category the IncomeCategory you want to find every Income of.
     * @return a List with every Income in incomes with the category.
     */
    public List<Income> getIncomeBasedOnCategory(IncomeCategory category){
        return incomes.stream().filter(anIncome -> anIncome.getCategory().compareTo(category) == 0).collect(Collectors.toList());
    }

}